# open-agent-api
An API for creating and interacting with AI agents, including chat completions,
autonomous agents with tool usage, multi-agent teams, knowledge base search,
and optional billing integration.
Clients can authenticate via magic link or OAuth2 to obtain a token, or use API keys.


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.7.0
- Package version: 0.7.0
- Generator version: 7.10.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.8+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import open_agent_api
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import open_agent_api
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import open_agent_api
from open_agent_api.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to https://localhost:8007/v1
# See configuration.py for a list of all supported configuration parameters.
configuration = open_agent_api.Configuration(
    host = "https://localhost:8007/v1"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization (JWT): BearerAuth
configuration = open_agent_api.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with open_agent_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = open_agent_api.AccountApi(api_client)
    key_id = 'key_id_example' # str | The UUID of the API key
    start_date = '2013-10-20' # date | Start date for filtering usage data (YYYY-MM-DD) (optional)
    end_date = '2013-10-20' # date | End date for filtering usage data (YYYY-MM-DD) (optional)
    group_by = day # str | Group usage data by time period (optional) (default to day)

    try:
        # Get API Key Usage
        api_response = api_instance.account_keys_get_usage_for_id(key_id, start_date=start_date, end_date=end_date, group_by=group_by)
        print("The response of AccountApi->account_keys_get_usage_for_id:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling AccountApi->account_keys_get_usage_for_id: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://localhost:8007/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AccountApi* | [**account_keys_get_usage_for_id**](docs/AccountApi.md#account_keys_get_usage_for_id) | **GET** /account/keys/{key_id}/usage | Get API Key Usage
*AccountApi* | [**create_api_key_auth_keys_post**](docs/AccountApi.md#create_api_key_auth_keys_post) | **POST** /account/keys | Create API Key
*AccountApi* | [**get_api_key_auth_keys_key_id_get**](docs/AccountApi.md#get_api_key_auth_keys_key_id_get) | **GET** /account/keys/{key_id} | Get API Key
*AccountApi* | [**get_user_account**](docs/AccountApi.md#get_user_account) | **GET** /account | Get Account
*AccountApi* | [**get_user_usage**](docs/AccountApi.md#get_user_usage) | **GET** /account/balance | Get Usage
*AccountApi* | [**list_api_keys_auth_keys_get**](docs/AccountApi.md#list_api_keys_auth_keys_get) | **GET** /account/keys | List API Keys
*AccountApi* | [**revoke_api_key_auth_keys_key_id_delete**](docs/AccountApi.md#revoke_api_key_auth_keys_key_id_delete) | **DELETE** /account/keys/{key_id} | Revoke API Key
*AccountApi* | [**topup_account_account_topup_post**](docs/AccountApi.md#topup_account_account_topup_post) | **POST** /account/topup | Topup Account
*AgentsApi* | [**agents_agent_id_delete**](docs/AgentsApi.md#agents_agent_id_delete) | **DELETE** /agents/{agentId} | Delete an agent
*AgentsApi* | [**agents_agent_id_get**](docs/AgentsApi.md#agents_agent_id_get) | **GET** /agents/{agentId} | Get agent details
*AgentsApi* | [**agents_agent_id_put**](docs/AgentsApi.md#agents_agent_id_put) | **PUT** /agents/{agentId} | Update an agent
*AgentsApi* | [**agents_agent_id_run_post**](docs/AgentsApi.md#agents_agent_id_run_post) | **POST** /agents/{agentId}/run | Interact with an agent (chat interface)
*AgentsApi* | [**agents_get**](docs/AgentsApi.md#agents_get) | **GET** /agents | List my agents
*AgentsApi* | [**agents_post**](docs/AgentsApi.md#agents_post) | **POST** /agents | Create a new agent
*AuthenticationApi* | [**auth_link_post**](docs/AuthenticationApi.md#auth_link_post) | **POST** /auth/link | Request a magic login link via email
*AuthenticationApi* | [**auth_link_verify_token_get**](docs/AuthenticationApi.md#auth_link_verify_token_get) | **GET** /auth/link/verify/{token} | Verify a magic link token
*AuthenticationApi* | [**auth_oauth_device_token_post**](docs/AuthenticationApi.md#auth_oauth_device_token_post) | **POST** /auth/oauth/device-token | OAuth2 device code token exchange
*AuthenticationApi* | [**auth_oauth_provider_callback_get**](docs/AuthenticationApi.md#auth_oauth_provider_callback_get) | **GET** /auth/oauth/{provider}/callback | OAuth2 callback endpoint
*AuthenticationApi* | [**auth_oauth_provider_get**](docs/AuthenticationApi.md#auth_oauth_provider_get) | **GET** /auth/oauth/{provider} | Initiate OAuth2 login flow
*AuthenticationApi* | [**check_verification_status_auth_verification_status_token_get**](docs/AuthenticationApi.md#check_verification_status_auth_verification_status_token_get) | **GET** /auth/link/status/{token} | Check Verification Status
*BillingApi* | [**stripe_webhook_post**](docs/BillingApi.md#stripe_webhook_post) | **POST** /stripe/webhook | Stripe webhook endpoint
*ChatApi* | [**chat_completions_post**](docs/ChatApi.md#chat_completions_post) | **POST** /chat/completions | Create a chat completion (OpenAI-compatible)
*ChatApi* | [**list_models_v1_models_get**](docs/ChatApi.md#list_models_v1_models_get) | **GET** /models | List Models
*MCPApi* | [**mcp_info_mcp_get**](docs/MCPApi.md#mcp_info_mcp_get) | **GET** /mcp/ | Mcp Info
*MCPApi* | [**messages_endpoint_mcp_messages_post**](docs/MCPApi.md#messages_endpoint_mcp_messages_post) | **POST** /mcp/messages | Messages Endpoint
*MCPApi* | [**sse_endpoint_mcp_sse_get**](docs/MCPApi.md#sse_endpoint_mcp_sse_get) | **GET** /mcp/sse | Sse Endpoint
*TeamsApi* | [**teams_get**](docs/TeamsApi.md#teams_get) | **GET** /teams | List my teams
*TeamsApi* | [**teams_post**](docs/TeamsApi.md#teams_post) | **POST** /teams | Create a new team of agents
*TeamsApi* | [**teams_team_id_get**](docs/TeamsApi.md#teams_team_id_get) | **GET** /teams/{teamId} | Get team details
*TeamsApi* | [**teams_team_id_run_post**](docs/TeamsApi.md#teams_team_id_run_post) | **POST** /teams/{teamId}/run | Run a team of agents
*ToolsApi* | [**get_tools**](docs/ToolsApi.md#get_tools) | **GET** /tools | List tools
*ToolsApi* | [**tools_tool_id_delete**](docs/ToolsApi.md#tools_tool_id_delete) | **DELETE** /tools/{tool_id} | Delete a tool
*ToolsApi* | [**tools_tool_id_get**](docs/ToolsApi.md#tools_tool_id_get) | **GET** /tools/{tool_id} | Get tool details
*DefaultApi* | [**health_health_get**](docs/DefaultApi.md#health_health_get) | **GET** /health | Health
*DefaultApi* | [**root_get**](docs/DefaultApi.md#root_get) | **GET** / | Root
*SubscriptionApi* | [**cancel_subscription_subscription_cancel_post**](docs/SubscriptionApi.md#cancel_subscription_subscription_cancel_post) | **DELETE** /account/subscriptions/{subscription_id} | Cancel Subscription
*SubscriptionApi* | [**create_subscription_subscription_subscribe_post**](docs/SubscriptionApi.md#create_subscription_subscription_subscribe_post) | **POST** /account/plans/{plan_id}/purchase | Create Subscription
*SubscriptionApi* | [**get_checkout_url_subscription_plans_plan_id_checkout_get**](docs/SubscriptionApi.md#get_checkout_url_subscription_plans_plan_id_checkout_get) | **GET** /account/plans/{plan_id}/checkout | Get Checkout URL
*SubscriptionApi* | [**get_current_subscription_subscription_current_get**](docs/SubscriptionApi.md#get_current_subscription_subscription_current_get) | **GET** /account/subscriptions | Get Current Subscriptions
*SubscriptionApi* | [**get_plan_subscription_plans_plan_id_get**](docs/SubscriptionApi.md#get_plan_subscription_plans_plan_id_get) | **GET** /account/plans/{plan_id} | Get Plan
*SubscriptionApi* | [**get_subscription_subscription_subscription_id_get**](docs/SubscriptionApi.md#get_subscription_subscription_subscription_id_get) | **GET** /account/subscriptions/{subscription_id} | Get Subscription
*SubscriptionApi* | [**list_subscription_plans_subscription_plans_get**](docs/SubscriptionApi.md#list_subscription_plans_subscription_plans_get) | **GET** /account/plans | List Subscription Plans
*SubscriptionApi* | [**stripe_webhook_subscription_webhook_post**](docs/SubscriptionApi.md#stripe_webhook_subscription_webhook_post) | **POST** /account/subscription/webhook | Stripe Webhook


## Documentation For Models

 - [AccountBalanceInfo](docs/AccountBalanceInfo.md)
 - [AccountInfo](docs/AccountInfo.md)
 - [AccountPortalSessionCreatedResponse](docs/AccountPortalSessionCreatedResponse.md)
 - [AccountSubscriptionInfo](docs/AccountSubscriptionInfo.md)
 - [AccountSubscriptionPurchase](docs/AccountSubscriptionPurchase.md)
 - [AccountTopupRequest](docs/AccountTopupRequest.md)
 - [AccountTopupResponse](docs/AccountTopupResponse.md)
 - [AccountUpdateRequest](docs/AccountUpdateRequest.md)
 - [AccountUsageInfo](docs/AccountUsageInfo.md)
 - [AccountUsageInfoItem](docs/AccountUsageInfoItem.md)
 - [Agent](docs/Agent.md)
 - [AgentCompletionChunk](docs/AgentCompletionChunk.md)
 - [AgentCompletionRequest](docs/AgentCompletionRequest.md)
 - [AgentCompletionResponse](docs/AgentCompletionResponse.md)
 - [AgentEnvironment](docs/AgentEnvironment.md)
 - [AgentMessage](docs/AgentMessage.md)
 - [AgentMessageCitations](docs/AgentMessageCitations.md)
 - [AgentMessageContent](docs/AgentMessageContent.md)
 - [AgentMessageMetrics](docs/AgentMessageMetrics.md)
 - [AgentMessageReferences](docs/AgentMessageReferences.md)
 - [AgentMessageToolCall](docs/AgentMessageToolCall.md)
 - [AgentMessageToolCallFunction](docs/AgentMessageToolCallFunction.md)
 - [AgentToolkitSummary](docs/AgentToolkitSummary.md)
 - [AgentsGet200Response](docs/AgentsGet200Response.md)
 - [ApiKeyCreationRequest](docs/ApiKeyCreationRequest.md)
 - [ApiKeyInfo](docs/ApiKeyInfo.md)
 - [ApiKeyUsageInfo](docs/ApiKeyUsageInfo.md)
 - [ApiKeyUsageResponse](docs/ApiKeyUsageResponse.md)
 - [ApiKeyUsageResponseTimeSeriesInner](docs/ApiKeyUsageResponseTimeSeriesInner.md)
 - [ApiKeyUsageResponseUsageData](docs/ApiKeyUsageResponseUsageData.md)
 - [ApiKeyUsageResponseUsageDataBillingInfo](docs/ApiKeyUsageResponseUsageDataBillingInfo.md)
 - [Audio](docs/Audio.md)
 - [AuthLinkVerifyTokenGet200Response](docs/AuthLinkVerifyTokenGet200Response.md)
 - [AuthLoginResponse](docs/AuthLoginResponse.md)
 - [AuthMagicLinkRequest](docs/AuthMagicLinkRequest.md)
 - [ChatCompletionRequest](docs/ChatCompletionRequest.md)
 - [ChatCompletionRequestStop](docs/ChatCompletionRequestStop.md)
 - [ChatCompletionResponse](docs/ChatCompletionResponse.md)
 - [ChatCompletionResponseChoicesInner](docs/ChatCompletionResponseChoicesInner.md)
 - [ChatCompletionUsage](docs/ChatCompletionUsage.md)
 - [CheckoutSessionInfo](docs/CheckoutSessionInfo.md)
 - [CheckoutSessionRequest](docs/CheckoutSessionRequest.md)
 - [Citations](docs/Citations.md)
 - [CostSummary](docs/CostSummary.md)
 - [CostSummaryEvent](docs/CostSummaryEvent.md)
 - [DocumentCitation](docs/DocumentCitation.md)
 - [ExternalTool](docs/ExternalTool.md)
 - [File](docs/File.md)
 - [Image](docs/Image.md)
 - [LocationInner](docs/LocationInner.md)
 - [Media](docs/Media.md)
 - [OAuthAuthorizationResponse](docs/OAuthAuthorizationResponse.md)
 - [OAuthCallbackResponse](docs/OAuthCallbackResponse.md)
 - [OAuthDeviceCodeRequest](docs/OAuthDeviceCodeRequest.md)
 - [OAuthDeviceCodeResponse](docs/OAuthDeviceCodeResponse.md)
 - [RunCompletedEvent](docs/RunCompletedEvent.md)
 - [RunResponseEvent](docs/RunResponseEvent.md)
 - [RunResponseEvent1](docs/RunResponseEvent1.md)
 - [RunStartedEvent](docs/RunStartedEvent.md)
 - [ServerSetupRequest](docs/ServerSetupRequest.md)
 - [ServerSetupResponse](docs/ServerSetupResponse.md)
 - [SseEndpointMcpSseGet200Response](docs/SseEndpointMcpSseGet200Response.md)
 - [SubscriptionPlanInfo](docs/SubscriptionPlanInfo.md)
 - [SubscriptionStatus](docs/SubscriptionStatus.md)
 - [SuccessResponse](docs/SuccessResponse.md)
 - [Team](docs/Team.md)
 - [TeamMembersInner](docs/TeamMembersInner.md)
 - [TeamMessage](docs/TeamMessage.md)
 - [TeamMessageCitations](docs/TeamMessageCitations.md)
 - [TeamRunRequest](docs/TeamRunRequest.md)
 - [TeamRunResponse](docs/TeamRunResponse.md)
 - [TeamsGet200Response](docs/TeamsGet200Response.md)
 - [TeamsPostRequest](docs/TeamsPostRequest.md)
 - [TeamsPostRequestMembersInner](docs/TeamsPostRequestMembersInner.md)
 - [TeamsTeamIdRunPost200Response](docs/TeamsTeamIdRunPost200Response.md)
 - [TeamsTeamIdRunPostRequest](docs/TeamsTeamIdRunPostRequest.md)
 - [ToolCall](docs/ToolCall.md)
 - [ToolCallCompletedEvent](docs/ToolCallCompletedEvent.md)
 - [ToolCallCompletedEvent1](docs/ToolCallCompletedEvent1.md)
 - [ToolCallResult](docs/ToolCallResult.md)
 - [ToolCallResultMetrics](docs/ToolCallResultMetrics.md)
 - [ToolCallStartedEvent](docs/ToolCallStartedEvent.md)
 - [ToolCallStartedEvent1](docs/ToolCallStartedEvent1.md)
 - [Toolkit](docs/Toolkit.md)
 - [ToolkitFunction](docs/ToolkitFunction.md)
 - [UrlCitation](docs/UrlCitation.md)
 - [Usage](docs/Usage.md)
 - [UserSubscriptionCreate](docs/UserSubscriptionCreate.md)
 - [UserSubscriptionResponse](docs/UserSubscriptionResponse.md)
 - [ValidationError](docs/ValidationError.md)
 - [Video](docs/Video.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="ApiKey"></a>
### ApiKey

- **Type**: API key
- **API key parameter name**: X-API-Key
- **Location**: HTTP header

<a id="BearerAuth"></a>
### BearerAuth

- **Type**: Bearer authentication (JWT)


## Author




