# coding: utf-8

"""
    Open Agent API

    An API for creating and interacting with AI agents, including chat completions, autonomous agents with tool usage, multi-agent teams, knowledge base search, and optional billing integration. Clients can authenticate via magic link or OAuth2 to obtain a token, or use API keys. 

    The version of the OpenAPI document: 0.7.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from open_agent_api.models.tool_call_result import ToolCallResult
from typing import Optional, Set
from typing_extensions import Self

class ToolCallCompletedEvent(BaseModel):
    """
    ToolCallCompletedEvent
    """ # noqa: E501
    run_id: StrictStr = Field(description="The unique identifier for the run")
    content: Optional[StrictStr] = Field(default=None, description="The content of the tool call completion")
    content_type: StrictStr = Field(description="The type of content")
    event: StrictStr = Field(description="The event type")
    model: Optional[StrictStr] = Field(default=None, description="The model used for the run")
    agent_id: Optional[StrictStr] = Field(default=None, description="The unique identifier for the agent")
    session_id: StrictStr = Field(description="The unique identifier for the session")
    created_at: StrictInt = Field(description="The timestamp when the tool call was completed")
    tools: Optional[List[ToolCallResult]] = Field(default=None, description="Details of the completed tool call")
    __properties: ClassVar[List[str]] = ["run_id", "content", "content_type", "event", "model", "agent_id", "session_id", "created_at", "tools"]

    @field_validator('event')
    def event_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['ToolCallCompleted']):
            raise ValueError("must be one of enum values ('ToolCallCompleted')")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ToolCallCompletedEvent from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of each item in tools (list)
        _items = []
        if self.tools:
            for _item_tools in self.tools:
                if _item_tools:
                    _items.append(_item_tools.to_dict())
            _dict['tools'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ToolCallCompletedEvent from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "run_id": obj.get("run_id"),
            "content": obj.get("content"),
            "content_type": obj.get("content_type"),
            "event": obj.get("event"),
            "model": obj.get("model"),
            "agent_id": obj.get("agent_id"),
            "session_id": obj.get("session_id"),
            "created_at": obj.get("created_at"),
            "tools": [ToolCallResult.from_dict(_item) for _item in obj["tools"]] if obj.get("tools") is not None else None
        })
        return _obj


